LLMQ Dashboard — LLM Quality Gate
Description: LLMQ Dashboard: Monitor LLM evaluation metrics, quality gates, regressions, and provider comparisons.

CI Mode Active Lightweight Metrics
Task Success
--
Relevance
--
Hallucination
--
Consistency
--
Gate Pass Rate
--

### Overall Score

--

### Last Run Summary

Loading...

### Metrics Over Time

### Provider Comparison

### Live Evaluations

Provider
Model
Dataset
Gate
Commit

### Evaluation Runs

0 runs

Provider / Model ↕ | Dataset ↕ | Commit ↕ | Score ↕ | Gate ↕ | Regression | Timestamp ↕
--- | --- | --- | --- | --- | --- | ---

### Run Details

Loading...

### Average Scores by Provider

### Metric Breakdown

### Provider Comparison Table

Provider / Model | Runs | Overall | Task Success | Relevance | Hallucination | Gate Rate | Trend
--- | --- | --- | --- | --- | --- | --- | ---

### Quality Gate History

### Gate Events

Run ID | Result | Overall Score | Failed Metrics | Commit | Timestamp
--- | --- | --- | --- | --- | ---

### Provider Configuration

Generator Provider
Generator Model
Judge Provider
Judge Model

### Quality Gate Thresholds

Task Success Threshold
Relevance Threshold
Hallucination Threshold
Consistency Threshold